@@ -132,7 +132,7 @@ sort_uid_cmp (gpointer enc,
 {
 	static gchar *sa1 = NULL, *sa2 = NULL;
 	static gint l1 = 0, l2 = 0;
-	gint a1, a2;
+	guint64 a1, a2;
 
 	if (l1 < len1 + 1) {
 		sa1 = g_realloc (sa1, len1 + 1);
@@ -145,8 +145,8 @@ sort_uid_cmp (gpointer enc,
 	strncpy (sa1, data1, len1); sa1[len1] = 0;
 	strncpy (sa2, data2, len2); sa2[len2] = 0;
 
-	a1 = strtoul (sa1, NULL, 10);
-	a2 = strtoul (sa2, NULL, 10);
+	a1 = g_ascii_strtoull (sa1, NULL, 10);
+	a2 = g_ascii_strtoull (sa2, NULL, 10);
 
 	return (a1 < a2) ? -1 : (a1 > a2) ? 1 : 0;
 }
